// @ts-check
import { defineConfig, envField } from "astro/config"
import paraglide from "@inlang/paraglide-astro"
import tailwind from "@astrojs/tailwind"
import sitemap from "@astrojs/sitemap"
import svelte from "@astrojs/svelte"
import node from "@astrojs/node"
import mdx from "@astrojs/mdx"
import icon from "astro-icon"

import { loadEnv } from "vite"

const { url } = process.env.URL
  ? loadEnv(process.env.URL, process.cwd(), "")
  : { url: "http://localhost:3000" }

// https://astro.build/config
export default defineConfig({
  site: url,
  output: "server",
  i18n: {
    defaultLocale: "nb",
    locales: ["nb", "en"]
  },
  integrations: [
    tailwind(),
    sitemap(),
    mdx(),
    svelte(),
    icon(),
    paraglide({
      // recommended settings
      project: "./project.inlang",
      outdir: "./src/paraglide" //where your files should be
    })
  ],
  adapter: node({
    mode: "standalone"
  }),
  env: {
    schema: {
      URL: envField.string({ context: "client", access: "public" })
    }
  }
})